@@ -14,7 +14,7 @@ from gi.repository import WebKit2WebExtension, GLib, GObject
 
 from urllib.parse import urlparse
 
-from eolie.define import Type, App
+from eolie.define import App
 from eolie.helper_passwords import PasswordsHelper
 from eolie.logger import Logger
 
@@ -173,7 +173,7 @@ class FormsExtension(GObject.Object):
     def pending_credentials(self):
         """
             Get credentials
-            @return (str, str, str, str, str, str)/None/Type.NONE
+            @return (str, str, str, str, str, str) or None
         """
         return self.__pending_credentials
 
@@ -198,46 +198,36 @@ class FormsExtension(GObject.Object):
             @param page_id as int
         """
         try:
-            # If credentials not found (!=Type.NONE) and something new
-            # is submitted
-            if self.__pending_credentials != Type.NONE and (
-                    attributes is None or
-                    attributes["login"] != user_form_value or
-                    password != pass_form_value):
-                if attributes is None or\
-                        attributes["login"] != user_form_value:
-                    uuid = ""
-                else:
+            self.__pending_credentials = (user_form_name,
+                                          user_form_value,
+                                          pass_form_name,
+                                          pass_form_value,
+                                          hostname_uri,
+                                          form_uri)
+
+            # New credential
+            if count == 0:
+                args = ("", user_form_name, user_form_value,
+                        pass_form_name, hostname_uri, form_uri)
+                variant = GLib.Variant.new_tuple(GLib.Variant("(ssssss)",
+                                                              args))
+                self.emit("submit-form", variant)
+            # Last credential
+            elif index == count - 1:
+                if attributes is not None:
                     uuid = attributes["uuid"]
-                self.__pending_credentials = (uuid,
-                                              user_form_name,
-                                              user_form_value,
-                                              pass_form_name,
-                                              pass_form_value,
-                                              hostname_uri,
-                                              form_uri)
-            else:
-                # Found, no more lookup
-                self.__pending_credentials = Type.NONE
-            # Last found credentials
-            if count < 1 or index == count - 1:
-                # Reset pending
-                if self.__pending_credentials == Type.NONE:
-                    self.__pending_credentials = None
-                # Ask for user input
-                elif self.__pending_credentials not in [None, Type.NONE]:
-                    (uuid,
-                     user_form_name,
-                     user_form_value,
-                     pass_form_name,
-                     pass_form_value,
-                     hostname_uri,
-                     form_uri) = self.__pending_credentials
-                    args = (uuid, user_form_name, user_form_value,
-                            pass_form_name, hostname_uri, form_uri)
-                    variant = GLib.Variant.new_tuple(GLib.Variant("(ssssss)",
-                                                                  args))
-                    self.emit("submit-form", variant)
+                    # No password change
+                    if attributes["login"] == user_form_value and\
+                            password == pass_form_value:
+                        return
+                    # New password
+                    elif attributes["login"] != user_form_value:
+                        uuid = ""
+                args = (uuid, user_form_name, user_form_value,
+                        pass_form_name, hostname_uri, form_uri)
+                variant = GLib.Variant.new_tuple(GLib.Variant("(ssssss)",
+                                                              args))
+                self.emit("submit-form", variant)
         except Exception as e:
             Logger.error("FormsExtension::__on_get_password(): %s", e)
 
@@ -257,6 +247,7 @@ class FormsExtension(GObject.Object):
             return
         try:
             # Check elements
+            self.__pending_credentials = None
             document = webpage.get_dom_document()
             username_idx = None
             password_idx = None
